@@ -44,7 +44,7 @@ print("\nNOTE: this Python executable used to create virtual environment:\n\t%s\
 #
 # The following taken from PyUtilib
 #
-if (sys.platform[0:3] == "win"): #pragma:nocover
+if sys.platform.startswith('win'): #pragma:nocover
     executable_extension=".exe"
 else:                            #pragma:nocover
     executable_extension=""
@@ -221,18 +221,18 @@ def unzip_file(filename, dir=None, verbose=False):
 class Repository(object):
 
     svn_get='checkout'
-    useEasyInstall = False
-    easy_install_path = ["easy_install"]
+    useEasyInstall = True
+    easy_install_path = None #["easy_install"]
     easy_install_flags = ['-q']
-    pip_path = ["pip"]
+    pip_path = None #["pip"]
     pip_flags = ['-q']
-    python = "python"
-    svn = "svn"
+    python = None #"python"
+    svn = "svn" + executable_extension
     dev = []
 
     def __init__(self, name, **kwds):
         class _TEMP_(object):
-            def __init__( self, root=None, trunk=None, stable=None, 
+            def __init__( self, root=None, trunk=None, 
                           release=None, tag=None, pyname=None, pypi=None, 
                           dev=False, username=None, install=True, rev=None, 
                           local=None, platform=None, version=None, 
@@ -262,16 +262,75 @@ class Repository(object):
                     self.config.exit = True
             else:
                 setattr(self.config, kwd, kwds[kwd])
+        #
+        self.offline=False
+        tmp = None
+        if self.config.local:
+            tmp = self.config.local
+        elif self.config.dev:
+            tmp = join(Installer.abshome_dir,'src', name)
+        else:
+            tmp = join(Installer.abshome_dir,'dist',name)
+        if tmp and os.path.exists(tmp):
+            self.offline=True
+        print("Repository %s %s %s" % (str(self.offline),tmp,name))
+        #
         self.initialize(self.config)
 
+    @staticmethod
+    def _configureExecutables(installer=None):
+        #
+        # Set the bin directory
+        #
+        if installer is not None:
+            if os.path.exists(installer.abshome_dir+os.sep+"Scripts"):
+                Repository.bindir = join(installer.abshome_dir,"Scripts")
+            else:
+                Repository.bindir = join(installer.abshome_dir,"bin")
+
+        bindir = Repository.bindir
+        if bindir is None:
+            print("(ERROR) installer called _configureExecutables() "
+                  "before _configureExecutables(installer)")
+            return
+
+        if Repository.python is None:
+            _path = os.path.abspath(join(bindir, 'jython.bat'))
+            if is_jython:
+                if os.path.exists(_path):
+                    Repository.python = _path
+            else:
+                _path = os.path.abspath(join(bindir, 'python'))
+                if sys.platform.startswith('win'):
+                    _path += 'w.exe'
+                if os.path.exists(_path):
+                    Repository.python = _path
+            if Repository.python is None:
+                print("(INFO) Virtualenv 'python' executable not found")
+        if Repository.easy_install_path is None:
+            _path = os.path.abspath(join(bindir, 'easy_install'))
+            if os.path.exists(_path):
+                Repository.easy_install_path = [Repository.python, _path]
+            elif os.path.exists(_path + '.exe'):
+                Repository.easy_install_path = [_path + '.exe']
+            else:
+                print("(INFO) Virtualenv 'easy_install' executable not found")
+        if Repository.pip_path is None:
+            _path = os.path.abspath(join(bindir, 'pip'))
+            if os.path.exists(_path):
+                Repository.pip_path = [Repository.python, _path]
+            elif os.path.exists(_path + '.exe'):
+                Repository.pip_path = [_path + '.exe']
+            else:
+                print("(INFO) Virtualenv 'pip' executable not found")
+ 
+
     def initialize(self, config):
         self.name = config.name
         self.root = config.root
         self.trunk = None
         self.trunk_root = None
         self.branch = None
-        self.stable = None
-        self.stable_root = None
         self.release = None
         self.tag = None
         self.release_root = None
@@ -305,9 +364,9 @@ class Repository(object):
             self.revarg=['-r',config.rev]
         self.install = config.install
 
-    def guess_versions(self, offline=False):
+    def guess_versions(self):
         if not self.config.root is None:
-            if not offline:
+            if not self.offline:
                 if using_subversion and not sys.platform.startswith('win'):
                     rootdir_output = subprocess.Popen(['svn','ls',self.config.root], stdout=subprocess.PIPE).communicate()[0]
                 else:
@@ -326,22 +385,14 @@ class Repository(object):
                 self.trunk = self.config.root+'/trunk'
             self.trunk_root = self.trunk
             try:
-                if offline or not 'stable' in rootdir_output:
-                    raise IOError
-                self.stable = guess_release(self.config.root+'/stable')
-                self.stable_root = self.stable
-            except (urllib2.HTTPError,IOError):
-                self.stable = None
-                self.stable_root = None
-            try:
-                if offline or not 'releases' in rootdir_output:
+                if self.offline or not 'releases' in rootdir_output:
                     raise IOError
                 self.release = guess_release(self.config.root+'/releases')
                 self.tag = None
                 self.release_root = self.release
             except (urllib2.HTTPError,IOError):
                 try:
-                    if offline or not 'tags' in rootdir_output:
+                    if self.offline or not 'tags' in rootdir_output:
                         raise IOError
                     self.release = guess_release(self.config.root+'/tags')
                     self.tag = self.release
@@ -354,11 +405,6 @@ class Repository(object):
                 self.trunk = self.config.trunk
             else:
                 self.trunk += self.config.trunk
-        if not self.config.stable is None:
-            if self.stable is None:
-                self.stable = self.config.stable
-            else:
-                self.stable += self.config.stable
         if not self.config.release is None:
             if self.release is None:
                 self.release = self.config.release
@@ -379,8 +425,6 @@ class Repository(object):
             print('root=%s' % config.root)
         if not config.trunk is None:
             print('trunk=%s' % config.trunk)
-        if not config.stable is None:
-            print('stable=%s' % config.stable)
         if not config.tag is None:
             print('tag=%s' % config.tag)
         elif not config.release is None:
@@ -407,12 +451,10 @@ class Repository(object):
         sys.stdout = sys.__stdout__
 
 
-    def find_pkgroot(self, trunk=False, stable=False, release=False):
+    def find_pkgroot(self, trunk=False, release=False):
         if trunk:
             if self.trunk is None:
-                if not self.stable is None:
-                    self.find_pkgroot(stable=True)
-                elif self.pypi is None and self.local is None:
+                if self.pypi is None and self.local is None:
                     self.find_pkgroot(release=True)
                 else:
                     # use easy_install
@@ -424,27 +466,9 @@ class Repository(object):
                 self.pkgroot = self.trunk_root
                 return
 
-        elif stable:
-            if self.stable is None:
-                if not self.release is None:
-                    self.find_pkgroot(release=True)
-                elif self.pypi is None and self.local is None:
-                    self.find_pkgroot(trunk=True)
-                else:
-                    # use easy_install
-                    self.pkgdir = None
-                    self.pkgroot = None
-                    return
-            else:
-                self.pkgdir = self.stable
-                self.pkgroot = self.stable_root
-                return
-
         elif release:
             if self.release is None:
-                if not self.stable is None:
-                    self.find_pkgroot(stable=True)
-                elif self.pypi is None and self.local is None:
+                if self.pypi is None and self.local is None:
                     self.find_pkgroot(trunk=True)
                 else:
                     # use easy_install
@@ -456,28 +480,24 @@ class Repository(object):
                 self.pkgroot = self.release_root
 
         else:
-            raise IOError("Must have one of trunk, stable or release specified: %s" % self.name)
+            raise IOError("Must have one of trunk or release specified: %s" % self.name)
 
 
-    def install_trunk(self, dir=None, install=True, preinstall=False, offline=False):
+    def install_trunk(self, dir=None, install=True, preinstall=False):
         self.find_pkgroot(trunk=True)
-        self.perform_install(dir=dir, install=install, preinstall=preinstall, offline=offline)
+        self.perform_install(dir=dir, install=install, preinstall=preinstall)
 
-    def install_stable(self, dir=None, install=True, preinstall=False, offline=False):
-        self.find_pkgroot(stable=True)
-        self.perform_install(dir=dir, install=install, preinstall=preinstall, offline=offline)
-
-    def install_release(self, dir=None, install=True, preinstall=False, offline=False):
+    def install_release(self, dir=None, install=True, preinstall=False):
         self.find_pkgroot(release=True)
-        self.perform_install(dir=dir, install=install, preinstall=preinstall, offline=offline)
+        self.perform_install(dir=dir, install=install, preinstall=preinstall)
 
-    def perform_install(self, dir=None, install=True, preinstall=False, offline=False):
+    def perform_install(self, dir=None, install=True, preinstall=False):
         if not self.platform_re is None and not self.platform_re.match(sys.platform):
             return
         if not self.version is None and not eval(self.version):
             return
         if self.pkgdir is None and self.local is None:
-            self.install_package(install, preinstall, dir, offline)
+            self.install_package(install, preinstall, dir)
             return
         if self.local:
             install = True
@@ -521,7 +541,7 @@ class Repository(object):
         if install:
             try:
                 if self.dev:
-                    if offline:
+                    if self.offline:
                         self.run([self.python, 'setup.py', 'develop', '--no-deps'], dir=dir)
                     else:
                         self.run([self.python, 'setup.py', 'develop'], dir=dir)
@@ -542,48 +562,25 @@ class Repository(object):
                     sys.exit(1)
                 print("Not aborting installer...")
 
-    def update_trunk(self, dir=None):
-        self.find_pkgroot(trunk=True)
-        self.perform_update(dir=dir)
-
-    def update_stable(self, dir=None):
-        self.find_pkgroot(stable=True)
-        self.perform_update(dir=dir)
-
-    def update_release(self, dir=None):
-        self.find_pkgroot(release=True)
-        self.perform_update(dir=dir)
-
-    def perform_update(self, dir=None):
-        if self.pkgdir is None:
-            self.upgrade_packages()
-            return
-        print("-----------------------------------------------------------------")
-        print("  Updating branch")
-        print("  Updating source for package "+self.name)
-        print("     Subversion dir: "+self.pkgdir)
-        print("     Source dir:     "+dir)
-        print("-----------------------------------------------------------------")
-        self.run([self.svn,'update','-q']+self.revarg+[dir])
-        if self.dev:
-            self.run([self.python, 'setup.py', 'develop'], dir=dir)
-        else:
-            self.run([self.python, 'setup.py', 'install'], dir=dir)
-
-    def install_package(self, install, preinstall, dir, offline):
+    def install_package(self, install, preinstall, dir):
+        Repository._configureExecutables()
         if Repository.useEasyInstall:
-            return self.easy_install(install, preinstall, dir, offline)
+            try:
+                return self.easy_install(install, preinstall, dir)
+            except:
+                print("ERROR installing with easy_install; falling back on PIP")
+            return self.pip_install(install, preinstall, dir)
         else:
             try:
-                return self.pip_install(install, preinstall, dir, offline)
+                return self.pip_install(install, preinstall, dir)
             except:
                 print("ERROR installing with PIP; falling back on easy_install")
-            return self.easy_install(install, preinstall, dir, offline)
+            return self.easy_install(install, preinstall, dir)
 
-    def easy_install(self, install, preinstall, dir, offline):
+    def easy_install(self, install, preinstall, dir):
         try:
             if install:
-                if offline:
+                if self.offline:
                     self.run([self.python, 'setup.py', 'install'], dir=dir)
                 else:
                     self.run( self.easy_install_path 
@@ -611,10 +608,10 @@ class Repository(object):
                 sys.exit(1)
             print("Not aborting installer...")
 
-    def pip_install(self, install, preinstall, dir, offline):
+    def pip_install(self, install, preinstall, dir):
         try:
             if install:
-                if offline:
+                if self.offline:
                     self.run([self.python, 'setup.py', 'install'], dir=dir)
                 else:
                     self.run( self.pip_path + ['install'] 
@@ -668,12 +665,6 @@ class Repository(object):
             os.chdir(cwd)
 
 
-if sys.platform.startswith('win'):
-    if not is_jython:
-        Repository.python += 'w.exe'
-    Repository.svn += '.exe'
-
-
 def filter_python_develop(line):
     if not line.strip():
         return Logger.DEBUG
@@ -695,11 +686,12 @@ wrapper = textwrap.TextWrapper(subsequent_indent="    ")
 
 class Installer(object):
 
+    abshome_dir = None
+
     def __init__(self):
         self.description="This script manages the installation of packages into a virtual Python installation."
         self.home_dir = None
         self.default_dirname='python'
-        self.abshome_dir = None
         self.sw_packages = []
         self.sw_dict = {}
         self.cmd_files = []
@@ -730,7 +722,7 @@ class Installer(object):
 """ % sys.argv[0]
 
     def add_repository(self, *args, **kwds):
-        if not 'root' in kwds and not 'pypi' in kwds and not 'release' in kwds and not 'trunk' in kwds and not 'stable' in kwds:
+        if not 'root' in kwds and not 'pypi' in kwds and not 'release' in kwds and not 'trunk' in kwds:
             raise IOError("No repository info specified for repository "+args[0])
         repos = Repository( *args, **kwds)
         if repos.name in self.sw_dict:
@@ -769,16 +761,10 @@ class Installer(object):
             dest='trunk',
             default=False)
 
-        parser.add_option('--stable',
-            help='Install stable branches of Python software using subversion.',
+        parser.add_option('--offline',
+            help='Disable the installation of offline packages',
             action='store_true',
-            dest='stable',
-            default=False)
-
-        parser.add_option('--update',
-            help='Update all Python packages.',
-            action='store_true',
-            dest='update',
+            dest='install_offline',
             default=False)
 
         parser.add_option('--proxy',
@@ -793,12 +779,6 @@ class Installer(object):
             dest='preinstall',
             default=False)
 
-        parser.add_option('--offline',
-            help='Perform installation offline, using source extracted from ZIP files.',
-            action='store_true',
-            dest='offline',
-            default=False)
-
         parser.add_option('--zip',
             help='Add ZIP files that are use define this installation.',
             action='append',
@@ -817,12 +797,26 @@ class Installer(object):
             dest='use_pythonpath',
             default=False)
 
-        parser.add_option(
-            '--site-packages',
-            dest='no_site_packages',
-            action='store_false',
-            help="Setup the virtual environment to use the global site-packages",
-            default=True)
+        # Historically, virtualenv used --no-site-packages, but
+        # recently, they moved to --system-site-packages /
+        # --no-site-packages.  Either way, they support the
+        # "--no-site-packages" option.  For portability, we will query
+        # that argument and set the default to the logical negation.
+        if not parser.has_option('--no-site-packages'):
+            raise RuntimeError(
+                "Internal VirtualEnv error: cannot determine the name of "
+                "the --no-site-packages option.  "
+                "Please report this to the PyUtilib Developers.")
+        site_packages_opt = parser.get_option('--no-site-packages')
+        if site_packages_opt.action == 'store_true':
+            parser.set_defaults(**dict([tuple([site_packages_opt.dest,False])]))
+        elif site_packages_opt.action == 'store_false':
+            parser.set_defaults(**dict([tuple([site_packages_opt.dest,True])]))
+        else:
+            raise RuntimeError(
+                "Internal VirtualEnv error: cannot determine the store "
+                "function for the --no-site-packages option.  "
+                "Please report this to the PyUtilib Developers.")
 
         parser.add_option(
             '-a', '--add-package',
@@ -874,13 +868,12 @@ class Installer(object):
         parser.remove_option("--relocatable")
         parser.remove_option("--version")
         parser.remove_option("--unzip-setuptools")
-        parser.remove_option("--no-site-packages")
         parser.remove_option("--clear")
         #
         # Add description
         #
         parser.description=self.description
-        parser.epilog="If DEST_DIR is not specified, then a default installation path is used:  "+self.default_windir+" on Windows and "+self.default_unixdir+" on Linux.  This command uses the Python 'setuptools' package to install Python packages.  This package installs packages by downloading files from the internet.  If you are running this from within a firewall, you may need to set the HTTP_PROXY environment variable to a value like 'http://<proxyhost>:<port>'."
+        parser.epilog="If DEST_DIR is not specified, then a default installation path is used:  "+self.default_windir+" on Windows and "+self.default_unixdir+" on Linux.  This command uses the Python 'pip' package to install Python packages.  This package installs packages by downloading files from the internet.  If you are running this from within a firewall, you may need to set the HTTP_PROXY environment variable to a value like 'http://<proxyhost>:<port>'."
 
 
     def adjust_options(self, options, args):
@@ -924,34 +917,21 @@ class Installer(object):
             print("")
             using_subversion = False
         #
-        if options.update and (options.stable or options.trunk):
-            self.logger.fatal("ERROR: cannot specify --stable or --trunk when specifying the --update option.")
-            sys.exit(1000)
-        if options.update and len(options.config_files) > 0:
-            self.logger.fatal("ERROR: cannot specify --config when specifying the --update option.")
-            sys.exit(1000)
-        if options.update and options.keep_config:
-            self.logger.fatal("ERROR: cannot specify --keep-config when specifying the --update option.")
-            sys.exit(1000)
         if len(args) > 1:
             self.logger.fatal("ERROR: installer script can only have one argument")
             sys.exit(1000)
         #
         # Error checking
         #
-        if not options.preinstall and (os.path.exists(self.abshome_dir) ^ options.update):
-            if options.update:
-                self.logger.fatal(wrapper.fill("ERROR: The 'update' option is specified, but the installation path '%s' does not exist!" % self.home_dir))
-                sys.exit(1000)
-            elif os.path.exists(join(self.abshome_dir,'bin')):
-                self.logger.fatal(wrapper.fill("ERROR: The installation path '%s' already exists!  Use the --update option if you wish to update, or remove this directory to create a fresh installation." % self.home_dir))
-                sys.exit(1000)
+        if not options.preinstall and os.path.exists(self.abshome_dir+os.sep+'bin'):
+            self.logger.fatal(wrapper.fill("ERROR: The installation path '%s' already exists! Remove this directory to create a fresh installation." % self.home_dir))
+            sys.exit(1000)
         if len(args) == 0:
             args.append(self.abshome_dir)
         #
         # Reset the config file if no options are specified
         #
-        if not self.config_file is None and not (options.trunk or options.stable or options.release):
+        if not self.config_file is None and not (options.trunk or options.release):
             self.config_file = os.path.dirname(self.config_file)+"/pypi.ini"
         #
         # If applying preinstall, then only do subversion exports
@@ -985,7 +965,7 @@ class Installer(object):
         else:
             home_dir = args[0]
         self.home_dir = home_dir
-        self.abshome_dir = os.path.abspath(home_dir)
+        Installer.abshome_dir = os.path.abspath(home_dir)
         if options.source is None:
             self.srcdir = join(self.abshome_dir,'src')
         else:
@@ -1007,28 +987,22 @@ class Installer(object):
     def setup_installer(self, options):
         if options.preinstall:
             print("Creating preinstall zip file in '%s'" % self.home_dir)
-        elif options.update:
-            print("Updating existing installation in '%s'" % self.home_dir)
         else:
             print("Starting fresh installation in '%s'" % self.home_dir)
         #
         # Setup HTTP proxy
         #
-        if options.offline:
-            os.environ['HTTP_PROXY'] = ''
-            os.environ['http_proxy'] = ''
-        else:
-            proxy = ''
-            if not options.proxy is None:
-                proxy = options.proxy
-            if proxy is '':
-                proxy = os.environ.get('HTTP_PROXY', '')
-            if proxy is '':
-                proxy = os.environ.get('http_proxy', '')
-            os.environ['HTTP_PROXY'] = proxy
-            os.environ['http_proxy'] = proxy
-            print("  using the HTTP_PROXY environment: %s" % proxy)
-            print("")
+        proxy = ''
+        if not options.proxy is None:
+            proxy = options.proxy
+        if proxy is '':
+            proxy = os.environ.get('HTTP_PROXY', '')
+        if proxy is '':
+            proxy = os.environ.get('http_proxy', '')
+        os.environ['HTTP_PROXY'] = proxy
+        os.environ['http_proxy'] = proxy
+        print("  using the HTTP_PROXY environment: %s" % proxy)
+        print("")
         #
         # Disable the PYTHONPATH, to isolate this installation from
         # other Python installations that a user may be working with.
@@ -1052,7 +1026,7 @@ class Installer(object):
         # When preinstalling or working offline, disable the
         # default install_setuptools() function.
         #
-        if options.offline:
+        if options.install_offline:
             install_setuptools.use_default=False
             install_distribute.use_default=False
             install_pip.use_default=False
@@ -1071,7 +1045,7 @@ class Installer(object):
         #
         # Parse config files
         #
-        if options.update or options.release:
+        if options.release:
             if os.path.exists(join(self.abshome_dir, 'admin', 'config.ini')):
                 self.config=None
                 options.config_files.append( join(self.abshome_dir, 'admin', 'config.ini') )
@@ -1093,20 +1067,19 @@ class Installer(object):
         print(" END - Configuration summary")
         print("-----------------------------------------------------------------")
         #
-        if options.preinstall or not options.offline:
-            #self.get_packages(options)
-            pass
-        else:
+        if not options.preinstall and not (options.trunk or options.release):
             self.sw_packages.insert( 0, Repository('virtualenv', pypi='virtualenv') )
             self.sw_packages.insert( 0, Repository('pip', pypi='pip') )
+            #if sys.version_info[:2] < (3,0):
+            #    self.sw_packages.insert( 0, Repository('setuptools', pypi='setuptools') )
+            #else:
+            #    self.sw_packages.insert( 0, Repository('distribute', pypi='distribute') )
             self.sw_packages.insert( 0, Repository('distribute', pypi='distribute') )
-            if sys.version_info[:2] < (3,0):
-                self.sw_packages.insert( 0, Repository('setuptools', pypi='setuptools') )
             #
             # Configure the package versions, for offline installs
             #
             for pkg in self.sw_packages:
-                pkg.guess_versions(True)
+                pkg.guess_versions()
 
     def get_packages(self, options):
         #
@@ -1116,20 +1089,12 @@ class Installer(object):
             os.mkdir(self.abshome_dir)
         if not os.path.exists(join(self.abshome_dir,'admin')):
             os.mkdir(join(self.abshome_dir,'admin'))
-        if options.update:
-            INPUT=open(join(self.abshome_dir,'admin',"virtualenv.cfg"),'r')
-            options.trunk = INPUT.readline().strip() != 'False'
-            options.stable = INPUT.readline().strip() != 'False'
-            options.release = INPUT.readline().strip() != 'False'
-            INPUT.close()
-        else:
-            sys.stdout = open(join(self.abshome_dir,'admin',"virtualenv.cfg"),'w')
-            print(options.trunk)
-            print(options.stable)
-            print(options.release)
-            sys.stdout.close()
-            sys.stdout = sys.__stdout__
-            self.write_config( join(self.abshome_dir,'admin','config.ini') )
+        sys.stdout = open(join(self.abshome_dir,'admin',"virtualenv.cfg"),'w')
+        print(options.trunk)
+        print(options.release)
+        sys.stdout.close()
+        sys.stdout = sys.__stdout__
+        self.write_config( join(self.abshome_dir,'admin','config.ini') )
         #
         # Setup package directories
         #
@@ -1144,12 +1109,16 @@ class Installer(object):
         #
         self.sw_packages.insert( 0, Repository('virtualenv', pypi='virtualenv') )
         self.sw_packages.insert( 0, Repository('pip', pypi='pip') )
+        #if sys.version_info[:2] < (3,0):
+        #    self.sw_packages.insert( 0, Repository('setuptools', pypi='setuptools') )
+        #else:
+        self.sw_packages.insert( 0, Repository('distribute', pypi='distribute') )
         if options.preinstall:
             #
             # When preinstalling, add the setuptools package to the installation list
             #
             self.sw_packages.insert( 0, Repository('distribute', pypi='distribute') )
-            self.sw_packages.insert( 0, Repository('setuptools', pypi='setuptools') )
+            #self.sw_packages.insert( 0, Repository('setuptools', pypi='setuptools') )
         for _pkg in options.packages:
             if os.path.exists(_pkg):
                 self.sw_packages.append( Repository(_pkg, local=os.path.abspath(_pkg)) )
@@ -1163,9 +1132,9 @@ class Installer(object):
         # Get package source
         #
         for pkg in self.sw_packages:
-            pkg.guess_versions(False)
+            pkg.guess_versions()
             if not pkg.install:
-                pkg.find_pkgroot(trunk=options.trunk, stable=options.stable, release=options.release)
+                pkg.find_pkgroot(trunk=options.trunk, release=options.release)
                 continue
             if pkg.local:
                 tmp = pkg.local
@@ -1174,15 +1143,10 @@ class Installer(object):
             else:
                 tmp = join(self.abshome_dir,'dist',pkg.name)
             if options.trunk:
-                if not options.update:
-                    pkg.install_trunk(dir=tmp, install=False, preinstall=options.preinstall, offline=options.offline)
-            elif options.stable:
-                if not options.update:
-                    pkg.install_stable(dir=tmp, install=False, preinstall=options.preinstall, offline=options.offline)
+                pkg.install_trunk(dir=tmp, install=False, preinstall=options.preinstall)
             else:
-                if not options.update:
-                    pkg.install_release(dir=tmp, install=False, preinstall=options.preinstall, offline=options.offline)
-        if options.update or not os.path.exists(join(self.abshome_dir,'doc')):
+                pkg.install_release(dir=tmp, install=False, preinstall=options.preinstall)
+        if not os.path.exists(join(self.abshome_dir,'doc')):
             self.install_auxdirs(options)
         #
         # Create a README.txt file
@@ -1220,34 +1184,15 @@ class Installer(object):
         pass
 
     def install_packages(self, options):
+        Repository._configureExecutables(self)
         #
-        # Set the bin directory
-        #
-        if os.path.exists(self.abshome_dir+os.sep+"Scripts"):
-            bindir = join(self.abshome_dir,"Scripts")
-        else:
-            bindir = join(self.abshome_dir,"bin")
-        if is_jython:
-            Repository.python = os.path.abspath(join(bindir, 'jython.bat'))
-        else:
-            Repository.python = os.path.abspath(join(bindir, 'python'))
-        if os.path.exists(os.path.abspath(join(bindir, 'easy_install'))):
-            Repository.easy_install_path = [Repository.python, os.path.abspath(join(bindir, 'easy_install'))]
-        else:
-            Repository.easy_install_path = [os.path.abspath(join(bindir, 'easy_install.exe'))]
-        if os.path.exists(os.path.abspath(join(bindir, 'pip'))):
-            Repository.pip_path = [Repository.python, os.path.abspath(join(bindir, 'pip'))]
-        else:
-            Repository.pip_path = [os.path.abspath(join(bindir, 'pip.exe'))]
-        #
-        if options.preinstall or not options.offline:
-            self.get_packages(options)
+        self.get_packages(options)
         #
         # Install the related packages
         #
         for pkg in self.sw_packages:
             if not pkg.install:
-                pkg.find_pkgroot(trunk=options.trunk, stable=options.stable, release=options.release)
+                pkg.find_pkgroot(trunk=options.trunk, release=options.release)
                 continue
             if pkg.local:
                 srcdir = pkg.local
@@ -1256,20 +1201,9 @@ class Installer(object):
             else:
                 srcdir = join(self.abshome_dir,'dist',pkg.name)
             if options.trunk:
-                if options.update:
-                    pkg.update_trunk(dir=srcdir)
-                else:
-                    pkg.install_trunk(dir=srcdir, preinstall=options.preinstall, offline=options.offline)
-            elif options.stable:
-                if options.update:
-                    pkg.update_stable(dir=srcdir)
-                else:
-                    pkg.install_stable(dir=srcdir, preinstall=options.preinstall, offline=options.offline)
+                pkg.install_trunk(dir=srcdir, preinstall=options.preinstall)
             else:
-                if options.update:
-                    pkg.update_release(dir=srcdir)
-                else:
-                    pkg.install_release(dir=srcdir, preinstall=options.preinstall, offline=options.offline)
+                pkg.install_release(dir=srcdir, preinstall=options.preinstall)
         #
         # Localize DOS cmd files
         #
@@ -1285,11 +1219,10 @@ class Installer(object):
         #
         # Misc notifications
         #
-        if not options.update:
-            print("")
-            print("-----------------------------------------------------------------")
-            print("  Add %s to the PATH environment variable" % (self.home_dir+os.sep+"bin"))
-            print("-----------------------------------------------------------------")
+        print("")
+        print("-----------------------------------------------------------------")
+        print("  Add %s to the PATH environment variable" % (self.home_dir+os.sep+"bin"))
+        print("-----------------------------------------------------------------")
         print("")
         print("Finished installation in '%s'" % self.home_dir)
 
@@ -1323,12 +1256,9 @@ class Installer(object):
     def install_auxdirs(self, options):
         for todir,pkg,fromdir in self.auxdir:
             pkgroot = self.sw_dict[pkg].pkgroot
-            if options.update:
-                cmd = [Repository.svn,'update','-q',self.svnjoin(self.abshome_dir, todir)]
-            else:
-                if options.clear:
-                    rmtree( join(self.abshome_dir,todir) )
-                cmd = [Repository.svn,Repository.svn_get,'-q',self.svnjoin(pkgroot,fromdir),join(self.abshome_dir,todir)]
+            if options.clear:
+                rmtree( join(self.abshome_dir,todir) )
+            cmd = [Repository.svn,Repository.svn_get,'-q',self.svnjoin(pkgroot,fromdir),join(self.abshome_dir,todir)]
             print("Running command '%s'" % " ".join(cmd))
             sys.stdout.flush()
             call_subprocess(cmd, filter_stdout=filter_python_develop,show_stdout=True)
